job

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2023 License: GPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the job type in the database.
	Label = "job"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the createdat field in the database.
	FieldCreatedAt = "created_at"
	// FieldLastModifiedAt holds the string denoting the lastmodifiedat field in the database.
	FieldLastModifiedAt = "last_modified_at"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldParams holds the string denoting the params field in the database.
	FieldParams = "params"
	// EdgeTome holds the string denoting the tome edge name in mutations.
	EdgeTome = "tome"
	// EdgeBundle holds the string denoting the bundle edge name in mutations.
	EdgeBundle = "bundle"
	// EdgeTasks holds the string denoting the tasks edge name in mutations.
	EdgeTasks = "tasks"
	// Table holds the table name of the job in the database.
	Table = "jobs"
	// TomeTable is the table that holds the tome relation/edge.
	TomeTable = "jobs"
	// TomeInverseTable is the table name for the Tome entity.
	// It exists in this package in order to avoid circular dependency with the "tome" package.
	TomeInverseTable = "tomes"
	// TomeColumn is the table column denoting the tome relation/edge.
	TomeColumn = "job_tome"
	// BundleTable is the table that holds the bundle relation/edge.
	BundleTable = "jobs"
	// BundleInverseTable is the table name for the File entity.
	// It exists in this package in order to avoid circular dependency with the "file" package.
	BundleInverseTable = "files"
	// BundleColumn is the table column denoting the bundle relation/edge.
	BundleColumn = "job_bundle"
	// TasksTable is the table that holds the tasks relation/edge.
	TasksTable = "tasks"
	// TasksInverseTable is the table name for the Task entity.
	// It exists in this package in order to avoid circular dependency with the "task" package.
	TasksInverseTable = "tasks"
	// TasksColumn is the table column denoting the tasks relation/edge.
	TasksColumn = "job_tasks"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "createdAt" field.
	DefaultCreatedAt func() time.Time
	// DefaultLastModifiedAt holds the default value on creation for the "lastModifiedAt" field.
	DefaultLastModifiedAt func() time.Time
	// UpdateDefaultLastModifiedAt holds the default value on update for the "lastModifiedAt" field.
	UpdateDefaultLastModifiedAt func() time.Time
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
)

Columns holds all SQL columns for job fields.

var ForeignKeys = []string{
	"job_tome",
	"job_bundle",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "jobs" table and are not defined as standalone fields in the schema.

Functions

func And

func And(predicates ...predicate.Job) predicate.Job

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.Job

CreatedAt applies equality check predicate on the "createdAt" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Job

CreatedAtEQ applies the EQ predicate on the "createdAt" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Job

CreatedAtGT applies the GT predicate on the "createdAt" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Job

CreatedAtGTE applies the GTE predicate on the "createdAt" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Job

CreatedAtIn applies the In predicate on the "createdAt" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Job

CreatedAtLT applies the LT predicate on the "createdAt" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Job

CreatedAtLTE applies the LTE predicate on the "createdAt" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Job

CreatedAtNEQ applies the NEQ predicate on the "createdAt" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Job

CreatedAtNotIn applies the NotIn predicate on the "createdAt" field.

func HasBundle

func HasBundle() predicate.Job

HasBundle applies the HasEdge predicate on the "bundle" edge.

func HasBundleWith

func HasBundleWith(preds ...predicate.File) predicate.Job

HasBundleWith applies the HasEdge predicate on the "bundle" edge with a given conditions (other predicates).

func HasTasks

func HasTasks() predicate.Job

HasTasks applies the HasEdge predicate on the "tasks" edge.

func HasTasksWith

func HasTasksWith(preds ...predicate.Task) predicate.Job

HasTasksWith applies the HasEdge predicate on the "tasks" edge with a given conditions (other predicates).

func HasTome

func HasTome() predicate.Job

HasTome applies the HasEdge predicate on the "tome" edge.

func HasTomeWith

func HasTomeWith(preds ...predicate.Tome) predicate.Job

HasTomeWith applies the HasEdge predicate on the "tome" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Job

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Job

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Job

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Job

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Job

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Job

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Job

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Job

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Job

IDNotIn applies the NotIn predicate on the ID field.

func LastModifiedAt

func LastModifiedAt(v time.Time) predicate.Job

LastModifiedAt applies equality check predicate on the "lastModifiedAt" field. It's identical to LastModifiedAtEQ.

func LastModifiedAtEQ

func LastModifiedAtEQ(v time.Time) predicate.Job

LastModifiedAtEQ applies the EQ predicate on the "lastModifiedAt" field.

func LastModifiedAtGT

func LastModifiedAtGT(v time.Time) predicate.Job

LastModifiedAtGT applies the GT predicate on the "lastModifiedAt" field.

func LastModifiedAtGTE

func LastModifiedAtGTE(v time.Time) predicate.Job

LastModifiedAtGTE applies the GTE predicate on the "lastModifiedAt" field.

func LastModifiedAtIn

func LastModifiedAtIn(vs ...time.Time) predicate.Job

LastModifiedAtIn applies the In predicate on the "lastModifiedAt" field.

func LastModifiedAtLT

func LastModifiedAtLT(v time.Time) predicate.Job

LastModifiedAtLT applies the LT predicate on the "lastModifiedAt" field.

func LastModifiedAtLTE

func LastModifiedAtLTE(v time.Time) predicate.Job

LastModifiedAtLTE applies the LTE predicate on the "lastModifiedAt" field.

func LastModifiedAtNEQ

func LastModifiedAtNEQ(v time.Time) predicate.Job

LastModifiedAtNEQ applies the NEQ predicate on the "lastModifiedAt" field.

func LastModifiedAtNotIn

func LastModifiedAtNotIn(vs ...time.Time) predicate.Job

LastModifiedAtNotIn applies the NotIn predicate on the "lastModifiedAt" field.

func Name

func Name(v string) predicate.Job

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Job

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Job

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Job

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Job

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Job

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Job

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Job

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Job

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Job

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Job

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Job

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Job

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Job

NameNotIn applies the NotIn predicate on the "name" field.

func Not

func Not(p predicate.Job) predicate.Job

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Job) predicate.Job

Or groups predicates with the OR operator between them.

func Params

func Params(v string) predicate.Job

Params applies equality check predicate on the "params" field. It's identical to ParamsEQ.

func ParamsContains

func ParamsContains(v string) predicate.Job

ParamsContains applies the Contains predicate on the "params" field.

func ParamsContainsFold

func ParamsContainsFold(v string) predicate.Job

ParamsContainsFold applies the ContainsFold predicate on the "params" field.

func ParamsEQ

func ParamsEQ(v string) predicate.Job

ParamsEQ applies the EQ predicate on the "params" field.

func ParamsEqualFold

func ParamsEqualFold(v string) predicate.Job

ParamsEqualFold applies the EqualFold predicate on the "params" field.

func ParamsGT

func ParamsGT(v string) predicate.Job

ParamsGT applies the GT predicate on the "params" field.

func ParamsGTE

func ParamsGTE(v string) predicate.Job

ParamsGTE applies the GTE predicate on the "params" field.

func ParamsHasPrefix

func ParamsHasPrefix(v string) predicate.Job

ParamsHasPrefix applies the HasPrefix predicate on the "params" field.

func ParamsHasSuffix

func ParamsHasSuffix(v string) predicate.Job

ParamsHasSuffix applies the HasSuffix predicate on the "params" field.

func ParamsIn

func ParamsIn(vs ...string) predicate.Job

ParamsIn applies the In predicate on the "params" field.

func ParamsIsNil

func ParamsIsNil() predicate.Job

ParamsIsNil applies the IsNil predicate on the "params" field.

func ParamsLT

func ParamsLT(v string) predicate.Job

ParamsLT applies the LT predicate on the "params" field.

func ParamsLTE

func ParamsLTE(v string) predicate.Job

ParamsLTE applies the LTE predicate on the "params" field.

func ParamsNEQ

func ParamsNEQ(v string) predicate.Job

ParamsNEQ applies the NEQ predicate on the "params" field.

func ParamsNotIn

func ParamsNotIn(vs ...string) predicate.Job

ParamsNotIn applies the NotIn predicate on the "params" field.

func ParamsNotNil

func ParamsNotNil() predicate.Job

ParamsNotNil applies the NotNil predicate on the "params" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to