Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Tag) predicate.Tag
- func HasSessions() predicate.Tag
- func HasSessionsWith(preds ...predicate.Session) predicate.Tag
- func ID(id int) predicate.Tag
- func IDEQ(id int) predicate.Tag
- func IDGT(id int) predicate.Tag
- func IDGTE(id int) predicate.Tag
- func IDIn(ids ...int) predicate.Tag
- func IDLT(id int) predicate.Tag
- func IDLTE(id int) predicate.Tag
- func IDNEQ(id int) predicate.Tag
- func IDNotIn(ids ...int) predicate.Tag
- func KindEQ(v Kind) predicate.Tag
- func KindIn(vs ...Kind) predicate.Tag
- func KindNEQ(v Kind) predicate.Tag
- func KindNotIn(vs ...Kind) predicate.Tag
- func KindValidator(k Kind) error
- func Name(v string) predicate.Tag
- func NameContains(v string) predicate.Tag
- func NameContainsFold(v string) predicate.Tag
- func NameEQ(v string) predicate.Tag
- func NameEqualFold(v string) predicate.Tag
- func NameGT(v string) predicate.Tag
- func NameGTE(v string) predicate.Tag
- func NameHasPrefix(v string) predicate.Tag
- func NameHasSuffix(v string) predicate.Tag
- func NameIn(vs ...string) predicate.Tag
- func NameLT(v string) predicate.Tag
- func NameLTE(v string) predicate.Tag
- func NameNEQ(v string) predicate.Tag
- func NameNotIn(vs ...string) predicate.Tag
- func Not(p predicate.Tag) predicate.Tag
- func Or(predicates ...predicate.Tag) predicate.Tag
- func ValidColumn(column string) bool
- type Kind
Constants ¶
const ( // Label holds the string label denoting the tag type in the database. Label = "tag" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldKind holds the string denoting the kind field in the database. FieldKind = "kind" // EdgeSessions holds the string denoting the sessions edge name in mutations. EdgeSessions = "sessions" // Table holds the table name of the tag in the database. Table = "tags" // SessionsTable is the table that holds the sessions relation/edge. The primary key declared below. SessionsTable = "session_tags" // SessionsInverseTable is the table name for the Session entity. // It exists in this package in order to avoid circular dependency with the "session" package. SessionsInverseTable = "sessions" )
Variables ¶
var Columns = []string{ FieldID, FieldName, FieldKind, }
Columns holds all SQL columns for tag fields.
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error )
var ( // SessionsPrimaryKey and SessionsColumn2 are the table columns denoting the // primary key for the sessions relation (M2M). SessionsPrimaryKey = []string{"session_id", "tag_id"} )
Functions ¶
func HasSessions ¶
HasSessions applies the HasEdge predicate on the "sessions" edge.
func HasSessionsWith ¶
HasSessionsWith applies the HasEdge predicate on the "sessions" edge with a given conditions (other predicates).
func KindValidator ¶
KindValidator is a validator for the "kind" field enum values. It is called by the builders before save.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type Kind ¶
type Kind string
Kind defines the type for the "kind" enum field.
func (Kind) MarshalGQL ¶
MarshalGQL implements graphql.Marshaler interface.
func (*Kind) UnmarshalGQL ¶
UnmarshalGQL implements graphql.Unmarshaler interface.