Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Job) predicate.Job
- func CreatedAt(v time.Time) predicate.Job
- func CreatedAtEQ(v time.Time) predicate.Job
- func CreatedAtGT(v time.Time) predicate.Job
- func CreatedAtGTE(v time.Time) predicate.Job
- func CreatedAtIn(vs ...time.Time) predicate.Job
- func CreatedAtLT(v time.Time) predicate.Job
- func CreatedAtLTE(v time.Time) predicate.Job
- func CreatedAtNEQ(v time.Time) predicate.Job
- func CreatedAtNotIn(vs ...time.Time) predicate.Job
- func HasBundle() predicate.Job
- func HasBundleWith(preds ...predicate.File) predicate.Job
- func HasTasks() predicate.Job
- func HasTasksWith(preds ...predicate.Task) predicate.Job
- func HasTome() predicate.Job
- func HasTomeWith(preds ...predicate.Tome) predicate.Job
- func ID(id int) predicate.Job
- func IDEQ(id int) predicate.Job
- func IDGT(id int) predicate.Job
- func IDGTE(id int) predicate.Job
- func IDIn(ids ...int) predicate.Job
- func IDLT(id int) predicate.Job
- func IDLTE(id int) predicate.Job
- func IDNEQ(id int) predicate.Job
- func IDNotIn(ids ...int) predicate.Job
- func LastModifiedAt(v time.Time) predicate.Job
- func LastModifiedAtEQ(v time.Time) predicate.Job
- func LastModifiedAtGT(v time.Time) predicate.Job
- func LastModifiedAtGTE(v time.Time) predicate.Job
- func LastModifiedAtIn(vs ...time.Time) predicate.Job
- func LastModifiedAtLT(v time.Time) predicate.Job
- func LastModifiedAtLTE(v time.Time) predicate.Job
- func LastModifiedAtNEQ(v time.Time) predicate.Job
- func LastModifiedAtNotIn(vs ...time.Time) predicate.Job
- func Name(v string) predicate.Job
- func NameContains(v string) predicate.Job
- func NameContainsFold(v string) predicate.Job
- func NameEQ(v string) predicate.Job
- func NameEqualFold(v string) predicate.Job
- func NameGT(v string) predicate.Job
- func NameGTE(v string) predicate.Job
- func NameHasPrefix(v string) predicate.Job
- func NameHasSuffix(v string) predicate.Job
- func NameIn(vs ...string) predicate.Job
- func NameLT(v string) predicate.Job
- func NameLTE(v string) predicate.Job
- func NameNEQ(v string) predicate.Job
- func NameNotIn(vs ...string) predicate.Job
- func Not(p predicate.Job) predicate.Job
- func Or(predicates ...predicate.Job) predicate.Job
- func Params(v string) predicate.Job
- func ParamsContains(v string) predicate.Job
- func ParamsContainsFold(v string) predicate.Job
- func ParamsEQ(v string) predicate.Job
- func ParamsEqualFold(v string) predicate.Job
- func ParamsGT(v string) predicate.Job
- func ParamsGTE(v string) predicate.Job
- func ParamsHasPrefix(v string) predicate.Job
- func ParamsHasSuffix(v string) predicate.Job
- func ParamsIn(vs ...string) predicate.Job
- func ParamsIsNil() predicate.Job
- func ParamsLT(v string) predicate.Job
- func ParamsLTE(v string) predicate.Job
- func ParamsNEQ(v string) predicate.Job
- func ParamsNotIn(vs ...string) predicate.Job
- func ParamsNotNil() predicate.Job
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the job type in the database. Label = "job" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the createdat field in the database. FieldCreatedAt = "created_at" // FieldLastModifiedAt holds the string denoting the lastmodifiedat field in the database. FieldLastModifiedAt = "last_modified_at" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldParams holds the string denoting the params field in the database. FieldParams = "params" // EdgeTome holds the string denoting the tome edge name in mutations. EdgeTome = "tome" // EdgeBundle holds the string denoting the bundle edge name in mutations. EdgeBundle = "bundle" // EdgeTasks holds the string denoting the tasks edge name in mutations. EdgeTasks = "tasks" // Table holds the table name of the job in the database. Table = "jobs" // TomeTable is the table that holds the tome relation/edge. TomeTable = "jobs" // TomeInverseTable is the table name for the Tome entity. // It exists in this package in order to avoid circular dependency with the "tome" package. TomeInverseTable = "tomes" // TomeColumn is the table column denoting the tome relation/edge. TomeColumn = "job_tome" // BundleTable is the table that holds the bundle relation/edge. BundleTable = "jobs" // BundleInverseTable is the table name for the File entity. // It exists in this package in order to avoid circular dependency with the "file" package. BundleInverseTable = "files" // BundleColumn is the table column denoting the bundle relation/edge. BundleColumn = "job_bundle" // TasksTable is the table that holds the tasks relation/edge. TasksTable = "tasks" // TasksInverseTable is the table name for the Task entity. // It exists in this package in order to avoid circular dependency with the "task" package. TasksInverseTable = "tasks" // TasksColumn is the table column denoting the tasks relation/edge. TasksColumn = "job_tasks" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "createdAt" field. DefaultCreatedAt func() time.Time // DefaultLastModifiedAt holds the default value on creation for the "lastModifiedAt" field. DefaultLastModifiedAt func() time.Time // UpdateDefaultLastModifiedAt holds the default value on update for the "lastModifiedAt" field. UpdateDefaultLastModifiedAt func() time.Time // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error )
var Columns = []string{ FieldID, FieldCreatedAt, FieldLastModifiedAt, FieldName, FieldParams, }
Columns holds all SQL columns for job fields.
var ForeignKeys = []string{
"job_tome",
"job_bundle",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "jobs" table and are not defined as standalone fields in the schema.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "createdAt" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "createdAt" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "createdAt" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "createdAt" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "createdAt" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "createdAt" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "createdAt" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "createdAt" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "createdAt" field.
func HasBundleWith ¶
HasBundleWith applies the HasEdge predicate on the "bundle" edge with a given conditions (other predicates).
func HasTasksWith ¶
HasTasksWith applies the HasEdge predicate on the "tasks" edge with a given conditions (other predicates).
func HasTomeWith ¶
HasTomeWith applies the HasEdge predicate on the "tome" edge with a given conditions (other predicates).
func LastModifiedAt ¶
LastModifiedAt applies equality check predicate on the "lastModifiedAt" field. It's identical to LastModifiedAtEQ.
func LastModifiedAtEQ ¶
LastModifiedAtEQ applies the EQ predicate on the "lastModifiedAt" field.
func LastModifiedAtGT ¶
LastModifiedAtGT applies the GT predicate on the "lastModifiedAt" field.
func LastModifiedAtGTE ¶
LastModifiedAtGTE applies the GTE predicate on the "lastModifiedAt" field.
func LastModifiedAtIn ¶
LastModifiedAtIn applies the In predicate on the "lastModifiedAt" field.
func LastModifiedAtLT ¶
LastModifiedAtLT applies the LT predicate on the "lastModifiedAt" field.
func LastModifiedAtLTE ¶
LastModifiedAtLTE applies the LTE predicate on the "lastModifiedAt" field.
func LastModifiedAtNEQ ¶
LastModifiedAtNEQ applies the NEQ predicate on the "lastModifiedAt" field.
func LastModifiedAtNotIn ¶
LastModifiedAtNotIn applies the NotIn predicate on the "lastModifiedAt" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func Params ¶
Params applies equality check predicate on the "params" field. It's identical to ParamsEQ.
func ParamsContains ¶
ParamsContains applies the Contains predicate on the "params" field.
func ParamsContainsFold ¶
ParamsContainsFold applies the ContainsFold predicate on the "params" field.
func ParamsEqualFold ¶
ParamsEqualFold applies the EqualFold predicate on the "params" field.
func ParamsHasPrefix ¶
ParamsHasPrefix applies the HasPrefix predicate on the "params" field.
func ParamsHasSuffix ¶
ParamsHasSuffix applies the HasSuffix predicate on the "params" field.
func ParamsIsNil ¶
ParamsIsNil applies the IsNil predicate on the "params" field.
func ParamsNotIn ¶
ParamsNotIn applies the NotIn predicate on the "params" field.
func ParamsNotNil ¶
ParamsNotNil applies the NotNil predicate on the "params" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.